@@ -16,7 +16,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: pdo_firebird.c 284399 2009-07-19 23:33:50Z felipe $ */
+/* $Id: pdo_firebird.c 289750 2009-10-19 15:34:50Z jani $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -38,7 +38,7 @@ zend_function_entry pdo_firebird_functions[] = { /* {{{ */
 /* {{{ pdo_firebird_deps
  */
 #if ZEND_MODULE_API_NO >= 20050922
-static const zend_module_dep pdo_firebird_deps[] = {
+static zend_module_dep pdo_firebird_deps[] = {
 	ZEND_MOD_REQUIRED("pdo")
 	{NULL, NULL, NULL}
 };
