@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php_spl.c,v 1.52.2.28.2.21 2009/06/13 17:35:37 cellog Exp $ */
+/* $Id: php_spl.c 286476 2009-07-28 22:25:31Z bjori $ */
 
 #ifdef HAVE_CONFIG_H
 	#include "config.h"
@@ -564,8 +564,9 @@ PHP_FUNCTION(spl_autoload_unregister)
  Return all registered __autoload() functionns */
 PHP_FUNCTION(spl_autoload_functions)
 {
-	zend_function *fptr, **func_ptr_ptr;
+	zend_function *fptr;
 	HashPosition function_pos;
+	autoload_func_info *alfi;
 
 	if (!EG(autoload_func)) {
 		if (zend_hash_find(EG(function_table), ZEND_AUTOLOAD_FUNC_NAME, sizeof(ZEND_AUTOLOAD_FUNC_NAME), (void **) &fptr) == SUCCESS) {
@@ -582,17 +583,22 @@ PHP_FUNCTION(spl_autoload_functions)
 		array_init(return_value);
 		zend_hash_internal_pointer_reset_ex(SPL_G(autoload_functions), &function_pos);
 		while(zend_hash_has_more_elements_ex(SPL_G(autoload_functions), &function_pos) == SUCCESS) {
-			zend_hash_get_current_data_ex(SPL_G(autoload_functions), (void **) &func_ptr_ptr, &function_pos);
-			if ((*func_ptr_ptr)->common.scope) {
+			zend_hash_get_current_data_ex(SPL_G(autoload_functions), (void **) &alfi, &function_pos);
+			if (alfi->func_ptr->common.scope) {
 				zval *tmp;
 				MAKE_STD_ZVAL(tmp);
 				array_init(tmp);
 
-				add_next_index_string(tmp, (*func_ptr_ptr)->common.scope->name, 1);
-				add_next_index_string(tmp, (*func_ptr_ptr)->common.function_name, 1);
+				if (alfi->obj) {
+					alfi->obj->refcount++;
+					add_next_index_zval(tmp, alfi->obj);
+				} else {
+					add_next_index_string(tmp, alfi->ce->name, 1);
+				}
+				add_next_index_string(tmp, alfi->func_ptr->common.function_name, 1);
 				add_next_index_zval(return_value, tmp);
 			} else
-				add_next_index_string(return_value, (*func_ptr_ptr)->common.function_name, 1);
+				add_next_index_string(return_value, alfi->func_ptr->common.function_name, 1);
 
 			zend_hash_move_forward_ex(SPL_G(autoload_functions), &function_pos);
 		}
