@@ -75,7 +75,7 @@ static xml_element_attr* new_attr(const char* key, const char* val) {
 }
 
 struct array_info {
-	char          kids_type[30];
+	char          kids_type[128];
 	unsigned long size;
 	/* ... ? */
 };
@@ -363,7 +363,7 @@ XMLRPC_VALUE xml_element_to_SOAP_REQUEST_worker(XMLRPC_REQUEST request,
 			}
 			else if (!strcmp(type, TOKEN_BASE64)) {
 				struct buffer_st buf;
-				base64_decode(&buf, el->text.str, el->text.len);
+				base64_decode_xmlrpc(&buf, el->text.str, el->text.len);
 				XMLRPC_SetValueBase64(xCurrent, buf.data, buf.offset);
 				buffer_delete(&buf);
 			}
@@ -529,7 +529,7 @@ xml_element* SOAP_to_xml_element_worker(XMLRPC_REQUEST request, XMLRPC_VALUE nod
 			{
 				struct buffer_st buf;
 				pAttrType = TOKEN_BASE64;
-				base64_encode(&buf, XMLRPC_GetValueBase64(node), XMLRPC_GetValueStringLen(node));
+				base64_encode_xmlrpc(&buf, XMLRPC_GetValueBase64(node), XMLRPC_GetValueStringLen(node));
 				simplestring_addn(&elem_val->text, buf.data, buf.offset );
 				buffer_delete(&buf);
 			}
