@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: network.c 288034 2009-09-04 07:59:48Z srinatar $ */
+/* $Id: network.c 289019 2009-09-30 20:48:41Z iliaa $ */
 
 /*#define DEBUG_MAIN_NETWORK 1*/
 
@@ -786,7 +786,7 @@ php_socket_t php_network_connect_socket_to_host(const char *host, unsigned short
 		switch (sa->sa_family) {
 #if HAVE_GETADDRINFO && HAVE_IPV6
 			case AF_INET6:
-				if (bindto && strchr(bindto, ':')) {
+				if (!bindto || strchr(bindto, ':')) {
 					((struct sockaddr_in6 *)sa)->sin6_family = sa->sa_family;
 					((struct sockaddr_in6 *)sa)->sin6_port = htons(port);
 					socklen = sizeof(struct sockaddr_in6);
