@@ -21,7 +21,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: cgi_main.c 281870 2009-06-09 13:29:39Z dsp $ */
+/* $Id: cgi_main.c 291497 2009-11-30 14:43:22Z dmitry $ */
 
 #include "php.h"
 #include "php_globals.h"
@@ -1496,8 +1496,9 @@ int main(int argc, char *argv[])
 			   in case some server does something different than above */
 			&& (!CGIG(redirect_status_env) || !getenv(CGIG(redirect_status_env)))
 			) {
-			SG(sapi_headers).http_response_code = 400;
-			PUTS("<b>Security Alert!</b> The PHP CGI cannot be accessed directly.\n\n\
+			zend_try {
+				SG(sapi_headers).http_response_code = 400;
+				PUTS("<b>Security Alert!</b> The PHP CGI cannot be accessed directly.\n\n\
 <p>This PHP CGI binary was compiled with force-cgi-redirect enabled.  This\n\
 means that a page will only be served up if the REDIRECT_STATUS CGI variable is\n\
 set, e.g. via an Apache Action directive.</p>\n\
@@ -1506,7 +1507,8 @@ manual page for CGI security</a>.</p>\n\
 <p>For more information about changing this behaviour or re-enabling this webserver,\n\
 consult the installation file that came with this distribution, or visit \n\
 <a href=\"http://php.net/install.windows\">the manual page</a>.</p>\n");
-
+			} zend_catch {
+			} zend_end_try();
 #if defined(ZTS) && !defined(PHP_DEBUG)
 			/* XXX we're crashing here in msvc6 debug builds at
 			   php_message_handler_for_zend:839 because
@@ -1936,13 +1938,16 @@ consult the installation file that came with this distribution, or visit \n\
 			running from shell (so fp == NULL), then fail.
 		*/
 		if (retval == FAILURE && file_handle.handle.fp == NULL) {
-			if (errno == EACCES) {
-				SG(sapi_headers).http_response_code = 403;
-				PUTS("Access denied.\n");
-			} else {
-				SG(sapi_headers).http_response_code = 404;
-				PUTS("No input file specified.\n");
-			}
+			zend_try {
+				if (errno == EACCES) {
+					SG(sapi_headers).http_response_code = 403;
+					PUTS("Access denied.\n");
+				} else {
+					SG(sapi_headers).http_response_code = 404;
+					PUTS("No input file specified.\n");
+				}
+			} zend_catch {
+			} zend_end_try();
 #if PHP_FASTCGI
 			/* we want to serve more requests if this is fastcgi
 			   so cleanup and continue, request shutdown is
